@@ -1,3 +1,6 @@
+#![allow(unknown_lints)]
+#![allow(unexpected_cfgs)]
+
 use std::env;
 use std::path::{Path, PathBuf};
 use std::process::Command;
@@ -10,7 +13,7 @@ fn main() {
         .file(manifest_dir.join("src/cxx.cc"))
         .cpp(true)
         .cpp_link_stdlib(None) // linked via link-cplusplus crate
-        .flag_if_supported(cxxbridge_flags::STD)
+        .std(cxxbridge_flags::STD)
         .warnings_into_errors(cfg!(deny_warnings))
         .compile("cxxbridge1");
 
@@ -24,13 +27,27 @@ fn main() {
     }
 
     if let Some(rustc) = rustc_version() {
-        if rustc.minor < 60 {
-            println!("cargo:warning=The cxx crate requires a rustc version 1.60.0 or newer.");
+        if rustc.minor >= 80 {
+            println!("cargo:rustc-check-cfg=cfg(built_with_cargo)");
+            println!("cargo:rustc-check-cfg=cfg(compile_error_if_alloc)");
+            println!("cargo:rustc-check-cfg=cfg(compile_error_if_std)");
+            println!("cargo:rustc-check-cfg=cfg(cxx_experimental_no_alloc)");
+            println!("cargo:rustc-check-cfg=cfg(error_in_core)");
+            println!("cargo:rustc-check-cfg=cfg(skip_ui_tests)");
+        }
+
+        if rustc.minor < 67 {
+            println!("cargo:warning=The cxx crate requires a rustc version 1.67.0 or newer.");
             println!(
                 "cargo:warning=You appear to be building with: {}",
                 rustc.version,
             );
         }
+
+        if rustc.minor >= 81 {
+            // core::error::Error
+            println!("cargo:rustc-cfg=error_in_core");
+        }
     }
 }
 
